@@ -350,7 +350,7 @@ PHP_METHOD(RdKafka, addBrokers)
 }
 /* }}} */
 
-/* {{{ proto RdKafka\Metadata::getMetadata(bool $all_topics, RdKafka\Topic $only_topic, int $timeout_ms)
+/* {{{ proto RdKafka\Metadata RdKafka::getMetadata(bool $all_topics, RdKafka\Topic $only_topic, int $timeout_ms)
    Request Metadata from broker */
 PHP_METHOD(RdKafka, getMetadata)
 {
@@ -388,7 +388,29 @@ PHP_METHOD(RdKafka, getMetadata)
     kafka_metadata_init(return_value, metadata);
 }
 /* }}} */
- 
+
+#ifdef HAS_RD_KAFKA_CONTROLLERID
+/* {{{ proto int RdKafka::getControllerId(int $timeout_ms)
+   Returns the current ControllerId (controller broker id) as reported in broker metadata */
+PHP_METHOD(RdKafka, getControllerId)
+{
+    kafka_object *intern;
+    zend_long timeout;
+
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "l", &timeout) == FAILURE) {
+        return;
+    }
+
+    intern = get_kafka_object(getThis());
+    if (!intern) {
+        return;
+    }
+
+    RETURN_LONG(rd_kafka_controllerid(intern->rk, timeout));
+}
+/* }}} */
+#endif
+
 /* {{{ proto void RdKafka::setLogLevel(int $level)
    Specifies the maximum logging level produced by internal kafka logging and debugging */
 PHP_METHOD(RdKafka, setLogLevel)
@@ -409,6 +431,165 @@ PHP_METHOD(RdKafka, setLogLevel)
 }
 /* }}} */
 
+#ifdef HAS_RD_KAFKA_OAUTHBEARER
+/* {{{ proto void RdKafka::oauthbearerSetToken(string $token_value, int|float|string $lifetime_ms, string $principal_name, array $extensions = [])
+ * Set SASL/OAUTHBEARER token and metadata
+ *
+ * The SASL/OAUTHBEARER token refresh callback or event handler should cause
+ * this method to be invoked upon success, via
+ * $kafka->oauthbearerSetToken(). The extension keys must not include the
+ * reserved key "`auth`", and all extension keys and values must conform to the
+ * required format as per https://tools.ietf.org/html/rfc7628#section-3.1:
+ *
+ * key            = 1*(ALPHA)
+ * value          = *(VCHAR / SP / HTAB / CR / LF )
+*/
+PHP_METHOD(RdKafka, oauthbearerSetToken)
+{
+    kafka_object *intern;
+    char *token_value;
+    size_t token_value_len;
+    zval *zlifetime_ms;
+    int64_t lifetime_ms;
+    char *principal_name;
+    size_t principal_len;
+    HashTable *extensions_hash = NULL;
+    
+    char errstr[512];
+    rd_kafka_resp_err_t ret = 0;
+
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "szs|h", &token_value, &token_value_len, &zlifetime_ms, &principal_name, &principal_len, &extensions_hash) == FAILURE) {
+        return;
+    }
+
+    /* On 32-bits, it might be required to pass $lifetime_ms as a float or a
+     * string */
+    switch (Z_TYPE_P(zlifetime_ms)) {
+        case IS_LONG:
+            lifetime_ms = (int64_t) Z_LVAL_P(zlifetime_ms);
+            break;
+        case IS_DOUBLE:
+            lifetime_ms = (int64_t) Z_DVAL_P(zlifetime_ms);
+            break;
+        case IS_STRING:;
+            char *str = Z_STRVAL_P(zlifetime_ms);
+            char *end;
+            lifetime_ms = (int64_t) strtoll(str, &end, 10);
+            if (end != str + Z_STRLEN_P(zlifetime_ms)) {
+                zend_throw_exception_ex(spl_ce_InvalidArgumentException, 0, "Argument #2 ($lifetime_ms) must be a valid integer");
+                return;
+            }
+            break;
+        EMPTY_SWITCH_DEFAULT_CASE();
+    }
+
+    intern = get_kafka_object(getThis());
+    if (!intern) {
+        return;
+    }    
+
+    errstr[0] = '\0';
+
+    int extensions_size = 0;
+    char **extensions = NULL;
+
+    if (extensions_hash != NULL) {
+        extensions_size = zend_hash_num_elements(extensions_hash) * 2;
+        extensions = safe_emalloc((extensions_size * 2), sizeof(char *), 0);
+
+        int pos = 0;
+        zend_ulong num_key;
+        zend_string *extension_key_str;
+        zval *extension_zval;
+        ZEND_HASH_FOREACH_KEY_VAL(extensions_hash, num_key, extension_key_str, extension_zval) {
+            if (!extension_key_str) {
+                extension_key_str = zend_long_to_str(num_key);
+                extensions[pos++] = estrdup(ZSTR_VAL(extension_key_str));
+                zend_string_release(extension_key_str);
+            } else {
+                extensions[pos++] = estrdup(ZSTR_VAL(extension_key_str));
+            }
+
+            zend_string *tmp_extension_val_str;
+            zend_string *extension_val_str = zval_get_tmp_string(extension_zval, &tmp_extension_val_str);
+            extensions[pos++] = estrdup(ZSTR_VAL(extension_val_str));
+            zend_tmp_string_release(tmp_extension_val_str);
+        } ZEND_HASH_FOREACH_END();
+    }    
+
+    ret = rd_kafka_oauthbearer_set_token(
+        intern->rk,
+        token_value,
+        lifetime_ms,
+        principal_name,
+        (const char **)extensions,
+        extensions_size,
+        errstr,
+        sizeof(errstr));
+
+    if (extensions != NULL) {
+        for (int i = 0; i < extensions_size; i++) {
+            efree(extensions[i]);
+        }
+        efree(extensions);
+    }
+    
+    switch (ret) {
+        case RD_KAFKA_RESP_ERR__INVALID_ARG:
+            zend_throw_exception(ce_kafka_exception, errstr, RD_KAFKA_RESP_ERR__INVALID_ARG);
+            return;
+        case RD_KAFKA_RESP_ERR__NOT_IMPLEMENTED:
+            zend_throw_exception(ce_kafka_exception, errstr, RD_KAFKA_RESP_ERR__NOT_IMPLEMENTED);
+            return;
+        case RD_KAFKA_RESP_ERR__STATE:
+            zend_throw_exception(ce_kafka_exception, errstr, RD_KAFKA_RESP_ERR__STATE);
+            return;
+        case RD_KAFKA_RESP_ERR_NO_ERROR:
+            break;
+        default:
+            return;
+    }
+}
+/* }}} */
+
+/* {{{ proto void RdKafka::oauthbearerSetTokenFailure(string $error)
+ The SASL/OAUTHBEARER token refresh callback or event handler should cause
+ this method to be invoked upon failure, via
+ rd_kafka_oauthbearer_set_token_failure().
+*/
+PHP_METHOD(RdKafka, oauthbearerSetTokenFailure)
+{
+    kafka_object *intern;
+    const char *errstr;
+    size_t errstr_len;
+
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &errstr, &errstr_len) == FAILURE) {
+        return;
+    }
+
+    intern = get_kafka_object(getThis());
+    if (!intern) {
+        return;
+    }    
+
+    rd_kafka_resp_err_t ret = rd_kafka_oauthbearer_set_token_failure(intern->rk, errstr);
+
+    switch (ret) {
+        case RD_KAFKA_RESP_ERR__INVALID_ARG:
+            zend_throw_exception(ce_kafka_exception, NULL, RD_KAFKA_RESP_ERR__INVALID_ARG);
+            return;
+        case RD_KAFKA_RESP_ERR__STATE:
+            zend_throw_exception(ce_kafka_exception, NULL, RD_KAFKA_RESP_ERR__STATE);
+            return;
+        case RD_KAFKA_RESP_ERR_NO_ERROR:
+            break;
+        default:
+            return;
+    }
+}
+/* }}} */
+#endif
+
 /* {{{ proto RdKafka\Topic RdKafka::newTopic(string $topic)
    Returns an RdKafka\Topic object */
 PHP_METHOD(RdKafka, newTopic)
@@ -562,7 +743,7 @@ PHP_METHOD(RdKafka, queryWatermarkOffsets)
     kafka_object *intern;
     char *topic;
     size_t topic_length;
-    long low, high;
+    int64_t low, high;
     zend_long partition, timeout;
     zval *lowResult, *highResult;
     rd_kafka_resp_err_t err;
@@ -586,8 +767,8 @@ PHP_METHOD(RdKafka, queryWatermarkOffsets)
         return;
     }
 
-    ZVAL_LONG(lowResult, low);
-    ZVAL_LONG(highResult, high);
+    ZVAL_LONG(lowResult, (zend_long) low);
+    ZVAL_LONG(highResult, (zend_long) high);
 }
 /* }}} */
 
